==> haskell-hasql-transaction-0.7.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.7.2
id: hasql-transaction-0.7.2-56eBPIn8lcF7QlWc7eihq8
key: hasql-transaction-0.7.2-56eBPIn8lcF7QlWc7eihq8
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
abi: 61754790bbf635c5f439d39cce9e8616
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Statements
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-transaction-0.7.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-transaction-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-transaction-0.7.2
hs-libraries: HShasql-transaction-0.7.2-56eBPIn8lcF7QlWc7eihq8
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    bytestring-tree-builder-0.2.7.3-4VLd0UuwlSCJ7Rdo0FWXTU
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    contravariant-extras-0.3.4-35VdvcJZeo7BMor95g7S78
    hasql-1.4-JFCu7M7Q934FGBcVhyQA4e mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-0.7.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.7.2
id: hasql-transaction-0.7.2-9ZtwNHSZKYK3XRCMzOuDta
key: hasql-transaction-0.7.2-9ZtwNHSZKYK3XRCMzOuDta
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
abi: e13a1d7921a3d9cb9218dc75e354fd02
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Statements
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-transaction-0.7.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-transaction-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-transaction-0.7.2
hs-libraries: HShasql-transaction-0.7.2-9ZtwNHSZKYK3XRCMzOuDta
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    bytestring-tree-builder-0.2.7.3-4VLd0UuwlSCJ7Rdo0FWXTU
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    contravariant-extras-0.3.4-35VdvcJZeo7BMor95g7S78
    hasql-1.4-3X4xEyp18On8VdTBwjc72v mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
